==> haskell-json-0.9.1-5-i686.pkg.tar.xz: usr/share/haskell/register/haskell-json.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: json
version: 0.9.1
id: json-0.9.1-FdE0ZgTaM4QFHc7XiJaWcu
key: json-0.9.1-FdE0ZgTaM4QFHc7XiJaWcu
license: BSD3
copyright: (c) 2007-2009 Galois Inc.
maintainer: Iavor S. Diatchki (iavor.diatchki@gmail.com)
synopsis: Support for serialising Haskell to and from JSON
description:
    JSON (JavaScript Object Notation) is a lightweight data-interchange
    format. It is easy for humans to read and write. It is easy for
    machines to parse and generate.  It is based on a subset of the
    JavaScript Programming Language, Standard ECMA-262 3rd Edition -
    December 1999.
    .
    This library provides a parser and pretty printer for converting
    between Haskell values and JSON.
category: Web
author: Galois Inc.
exposed: True
exposed-modules:
    Text.JSON Text.JSON.Types Text.JSON.String Text.JSON.ReadP
    Text.JSON.Generic Text.JSON.Pretty
abi: 9348953cfcc2c71bb4281e38645048ac
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/json-0.9.1
library-dirs: /usr/lib/ghc-8.0.1/site-local/json-0.9.1
data-dir: /usr/share/i386-linux-ghc-8.0.1/json-0.9.1
hs-libraries: HSjson-0.9.1-FdE0ZgTaM4QFHc7XiJaWcu
depends:
    array-0.5.1.1 base-4.9.0.0 bytestring-0.10.8.1 containers-0.5.7.1
    mtl-2.2.1-6qsR1PHUy5lL47Hpoa4jCM pretty-1.1.3.3
    syb-0.6-C65vWCsht6A8uLstpQIXyj text-1.2.2.1-FgcR4Xf0VlEHD9HLxzq9WJ
haddock-interfaces: /usr/share/doc/haskell-json/html/json.haddock
haddock-html: /usr/share/doc/haskell-json/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-json-0.9.1-6-i686.pkg.tar.xz: usr/share/haskell/register/haskell-json.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: json
version: 0.9.1
id: json-0.9.1-1fdEqAVygB8BY1q7RKjRg3
key: json-0.9.1-1fdEqAVygB8BY1q7RKjRg3
license: BSD3
copyright: (c) 2007-2009 Galois Inc.
maintainer: Iavor S. Diatchki (iavor.diatchki@gmail.com)
synopsis: Support for serialising Haskell to and from JSON
description:
    JSON (JavaScript Object Notation) is a lightweight data-interchange
    format. It is easy for humans to read and write. It is easy for
    machines to parse and generate.  It is based on a subset of the
    JavaScript Programming Language, Standard ECMA-262 3rd Edition -
    December 1999.
    .
    This library provides a parser and pretty printer for converting
    between Haskell values and JSON.
category: Web
author: Galois Inc.
exposed: True
exposed-modules:
    Text.JSON Text.JSON.Types Text.JSON.String Text.JSON.ReadP
    Text.JSON.Generic Text.JSON.Pretty
abi: 9c67a8576fc14953173a9f88a424613c
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/json-0.9.1
library-dirs: /usr/lib/ghc-8.0.1/site-local/json-0.9.1
data-dir: /usr/share/i386-linux-ghc-8.0.1/json-0.9.1
hs-libraries: HSjson-0.9.1-1fdEqAVygB8BY1q7RKjRg3
depends:
    array-0.5.1.1 base-4.9.0.0 bytestring-0.10.8.1 containers-0.5.7.1
    mtl-2.2.1-6qsR1PHUy5lL47Hpoa4jCM pretty-1.1.3.3
    syb-0.6-C65vWCsht6A8uLstpQIXyj text-1.2.2.2-9rr3K4o0GAG9P33dGDnV9v
haddock-interfaces: /usr/share/doc/haskell-json/html/json.haddock
haddock-html: /usr/share/doc/haskell-json/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
